package App::Icli;

use strict;
use warnings;
use 5.010;

our $VERSION = '0.48';

1;

__END__

=head1 NAME

App::Icli - Icinga Command Line Interface

=head1 SYNOPSIS

None.

=head1 VERSION

version 0.48

=head1 DESCRIPTION

This is a transitional module and does not yet offer any functionality.
Please refer to icli(1) and App::Icli::ConfigData(3pm) for documentation.

=head1 METHODS

None.

=head1 DIAGNOSTICS

None.

=head1 BUGS AND LIMITATIONS

None.

=head1 DEPENDENCIES

None.

=head1 SEE ALSO

App::Icli::ConfigData(3pm)

=head1 AUTHOR

Copyright (C) 2014 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>

=head1 LICENSE

  0. You just DO WHAT THE FUCK YOU WANT TO.
